show.c

LISP Interpreter Run

[[[
 Show that a formal system of complexity N
 can't determine more than N + 2933 bits of Omega.
 Formal system is a never halting lisp expression
 that displays lists of the form (10X0XXXX10).
 This stands for the fractional part of Omega,
 and means that these 0,1 bits of Omega are known.
 X stands for an unknown bit.
]]]

[Count number of bits in an omega that are determined.]
& (Cw) /.w() /=X+w C-w *1C-w

C:          (&(w)(/(.w)()(/(=X(+w))(C(-w))(*1(C(-w))))))

C'(XXX)

expression  (C('(XXX)))
value       ()

C'(1XX)

expression  (C('(1XX)))
value       (1)

C'(1X0)

expression  (C('(1X0)))
value       (11)

C'(110)

expression  (C('(110)))
value       (111)


[Merge bits of data into unknown bits of an omega.]
& (Mw) /.w() * /=X+w@+w M-w

M:          (&(w)(/(.w)()(*(/(=X(+w))(@)(+w))(M(-w)))))

[Test it.]
++?0 ':(Mw)/.w()*/=X+w@+wM-w M'(00X00X00X) '(111)

expression  (+(+(?0('(('(&(M)(M('(00X00X00X)))))('(&(w)(/(.w)(
            )(*(/(=X(+w))(@)(+w))(M(-w))))))))('(111)))))
value       (001001001)

++?0 ':(Mw)/.w()*/=X+w@+wM-w M'(11X11X111) '(00)

expression  (+(+(?0('(('(&(M)(M('(11X11X111)))))('(&(w)(/(.w)(
            )(*(/(=X(+w))(@)(+w))(M(-w))))))))('(00)))))
value       (110110111)


[(<xy) tells if x is less than y.]
& (<xy) /.y0 /.x1 <-x-y

<:          (&(xy)(/(.y)0(/(.x)1(<(-x)(-y)))))

<'(11)'(11)

expression  (<('(11))('(11)))
value       0

<'(11)'(111)

expression  (<('(11))('(111)))
value       1

<'(111)'(11)

expression  (<('(111))('(11)))
value       0


[
 Examine omegas in list w to see if in any one of them
 the number of bits that are determined is greater than n.
 Returns 0 to indicate not found, or what it found.
]
& (Ewn) /.w 0 /<nC+w +w E-wn

E:          (&(wn)(/(.w)0(/(<n(C(+w)))(+w)(E(-w)n))))

E'((00)(000))'()

expression  (E('((00)(000)))('()))
value       (00)

E'((00)(000))'(1)

expression  (E('((00)(000)))('(1)))
value       (00)

E'((00)(000))'(11)

expression  (E('((00)(000)))('(11)))
value       (000)

E'((00)(000))'(111)

expression  (E('((00)(000)))('(111)))
value       0

E'((00)(000))'(1111)

expression  (E('((00)(000)))('(1111)))
value       0


++?0'!%  [ The universal computer U ]
         [ Put together program for U : ]

^#~'     [ Show crucial prefix so that we can size it ]
"(       [ begin literally ]

[Count number of bits in an omega that are determined.]
: (Cw) /.w() /=X+w C-w *1C-w

[Merge bits of data into unknown bits of an omega.]
: (Mw) /.w() * /=X+w@+w M-w

[(<xy) tells if x is less than y.]
: (<xy) /.y1 /.x1 <-x-y    [[FORCED TO "TRUE" FOR TEST]]

[
 Examine omegas in list w to see if in any one of them
 the number of bits that are determined is greater than n.
 Returns 0 to indicate not found, or what it found.
]
: (Ewn) /.w 0 /<nC+w +w E-wn

[
 We know that H(Omega_n) > n - 1883 (see omega2.l).
 Size of this program is 1050 + bits of FAS read + missing bits of Omega.
 Program tries to output this many + 1883 bits of Omega.
 But that would give us a program whose output is more complex
 than the size of the program.  Contradiction!
 Thus this program won't find what it is looking for.
 So FAS of complexity N cannot determine > N + 1883 + 1050 bits of Omega,
 i.e., > N + 2933 bits of Omega.
]
[Main Loop: t is depth limit (time),
            b is bits of FAS read so far (buffer).]
:(Ltb)
 :v      ?t'!%b       [Run FAS again.]
 :s      E-v^b'{2933} [Look for an omega with >
                       (size of this program + 1883) bits determined.]
 /s      Ms           [Found it!  Merge in undetermined bits,
                       output result, and halt.]
 /="!+v  L   t ^b*@() [Read another bit of FAS.]
 /="?+v  L *1t  b     [Increase depth/time limit.]
 "?                   [Surprise, formal system halts,
                       so we do too.]

L()()                 [Initially, 0 depth limit
                       and no bits read.]
 )                    [end literally]

^#'"(
,'(1X0) [Toy formal system with only one theorem.]
    )

'(0) [Missing bit of omega that is needed.]

expression  (+(+(?0('(!(%)))(^(#(~('(:(Cw)/.w()/=X+wC-w*1C-w:(
            Mw)/.w()*/=X+w@+wM-w:(<xy)/.y1/.x1<-x-y:(Ewn)/.w0/
            <nC+w+wE-wn:(Ltb):v?t'!%b:sE-v^b'{2933}/sMs/="!+vL
            t^b*@()/="?+vL*1tb"?L()()))))(^(#('(,'(1X0))))('(0
            )))))))
show        (:(Cw)/.w()/=X+wC-w*1C-w:(Mw)/.w()*/=X+w@+wM-w:(<x
            y)/.y1/.x1<-x-y:(Ewn)/.w0/<nC+w+wE-wn:(Ltb):v?t'!%
            b:sE-v^b'{2933}/sMs/="!+vLt^b*@()/="?+vL*1tb"?L()(
            ))
size        150/1050
value       (100)

End of LISP Run

Elapsed time is 0 seconds.
