show.c

LISP Interpreter Run

[[[ Show that a formal system of lisp complexity H_L (FAS) = N
    cannot enable us to exhibit an S-expression with lisp complexity
    greater than N + 127.
    Setting: formal axiomatic system is never-ending lisp expression
    that displays pairs (s-expression x, unary number n)
    with H_L (x) >= n.
]]]

[ Idea is to have a program P search for something X that can be proved
  to be more complex than P is, and therefore P can never find X.
  I.e., idea is to show that if this program halts we get a contradiction,
  and therefore the program doesn't halt. ]

!++?0'%#~'"( [begin literally]

[ | = |x| = size in characters of s-expression x. ]
:(|x) /=x()'{2} /.x'{1} ^|+x|-x

[ < = unary number x is less than unary number y ]
[ x and y are lists of 1's ]
:(<xy) /.y1 /.x1 <-x-y               [[FORCE VALUE "TRUE" FOR TEST]]

[ E = examine list x for first s in pair (s,m) with H_L (s) >= m > n. ]
[ If not found returns false/0. ]
:(Exn) /.x0 /<n+-+x ++x E-xn

[ Here we are given the formal axiomatic system FAS. ]
:f '"( ,'((xy)(111)) )       [[FAS = {"H((xy)) >= 3"}. |FAS| = 13.]]

[ n = number of characters in this program including the FAS. ]
:n ~^--|f '{127}     [Show that this m-exp knows its own size.]
[ n = 127 + |FAS| ]

[ L = loop running the formal axiomatic system ]
:(Lt)
  :v ?t'!%#f  [Run the formal system for t time steps.]
  :s E-vn     [Have we found an s-exp more complex than this program?]
  /s s        [If found s-exp more complex than this program,
               return it as our value (contradiction!)]
         [This m-exp's value is an s-exp of complexity > 127 + |FAS|.
          But this m-exp's size is 127 + |FAS|!  Impossible!]
  /.+v L*1t   [If not, keep looping]
  "?          [or halt if formal system halted.]
L()           [Start loop running with t = 0.]

) [end literally]

expression  (!(+(+(?0('(%))(#(~('(:(|x)/=x()'{2}/.x'{1}^|+x|-x
            :(<xy)/.y1/.x1<-x-y:(Exn)/.x0/<n+-+x++xE-xn:f'"(,'
            ((xy)(111))):n~^--|f'{127}:(Lt):v?t'!%#f:sE-vn/ss/
            .+vL*1t"?L()))))))))
show        (:(|x)/=x()'{2}/.x'{1}^|+x|-x:(<xy)/.y1/.x1<-x-y:(
            Exn)/.x0/<n+-+x++xE-xn:f'"(,'((xy)(111))):n~^--|f'
            {127}:(Lt):v?t'!%#f:sE-vn/ss/.+vL*1t"?L())
size        140/980
show        (1111111111111111111111111111111111111111111111111
            11111111111111111111111111111111111111111111111111
            11111111111111111111111111111111111111111)
size        140/980
value       (xy)

End of LISP Run

Elapsed time is 0 seconds.
